@@ -104,11 +104,13 @@ HashMgr::HashMgr(const char* tpath, const char* apath, const char* key)
   if (ec) {
     /* error condition - what should we do here */
     HUNSPELL_WARNING(stderr, "Hash Manager Error : %d\n", ec);
-    if (tableptr) {
-      free(tableptr);
-      tableptr = NULL;
+    free(tableptr);
+    //keep tablesize to 1 to fix possible division with zero
+    tablesize = 1;
+    tableptr = (struct hentry**)calloc(tablesize, sizeof(struct hentry*));
+    if (!tableptr) {
+      tablesize = 0;
     }
-    tablesize = 0;
   }
 }
 
@@ -386,6 +388,7 @@ int HashMgr::remove(const std::string& word) {
       for (int i = 0; i < dp->alen; i++)
         flags[i] = dp->astr[i];
       flags[dp->alen] = forbiddenword;
+      free(dp->astr);
       dp->astr = flags;
       dp->alen++;
       std::sort(flags, flags + dp->alen);
@@ -415,6 +418,7 @@ int HashMgr::remove_forbidden_flag(const std::string& word) {
             flags2[j++] = dp->astr[i];
         }
         dp->alen--;
+        free(dp->astr);
         dp->astr = flags2;  // XXX allowed forbidden words
       }
     }
@@ -639,8 +643,8 @@ int HashMgr::decode_flags(unsigned short** result, const std::string& flags, Fil
       if (!*result)
         return -1;
       for (int i = 0; i < len; i++) {
-        (*result)[i] = (((unsigned short)flags[i * 2]) << 8) +
-                       (unsigned short)flags[i * 2 + 1];
+        (*result)[i] = ((unsigned short)((unsigned char)flags[i * 2]) << 8) +
+                       (unsigned char)flags[i * 2 + 1];
       }
       break;
     }
@@ -722,8 +726,8 @@ bool HashMgr::decode_flags(std::vector<unsigned short>& result, const std::strin
       len /= 2;
       result.reserve(result.size() + len);
       for (size_t i = 0; i < len; ++i) {
-        result.push_back((((unsigned short)flags[i * 2]) << 8) +
-                         (unsigned short)flags[i * 2 + 1]);
+        result.push_back(((unsigned short)((unsigned char)flags[i * 2]) << 8) +
+                         (unsigned char)flags[i * 2 + 1]);
       }
       break;
     }
@@ -779,7 +783,7 @@ unsigned short HashMgr::decode_flag(const char* f) const {
   int i;
   switch (flag_mode) {
     case FLAG_LONG:
-      s = ((unsigned short)f[0] << 8) + (unsigned short)f[1];
+      s = ((unsigned short)((unsigned char)f[0]) << 8) + (unsigned char)f[1];
       break;
     case FLAG_NUM:
       i = atoi(f);
